==> cetus-5.3.5.tgz: package/payments/index.js <==
"use strict";

let _ =   					require('underscore'),
	stripe =				null,
	utilities =   			require('../utilities/index'),
	config =   				require('./config'),
	logErrorAndReturn =     function (e, result, callback) {
                                let err = null;
                                if (e) {
                                    err = new utilities.error.aws (e.code);
                                    utilities.logger.error(e.stack);
                                }
                                if (callback) return callback (err, result);
                            },
    initilized =            false,
    returnSuccess =         function (parent) { return (data) => parent (null, data) },
    returnError =           function (parent) { return function (err) {
                                utilities.logger.error(err);
                                return parent (new utilities.error.stp (err.type));
                            };};




function createCharge (data) {
    return stripe.charges.create ({
        amount:             data.amount,
        currency:           data.currency,
        destination:        data.destination,
        source:             data.ccToken,
        // customer:           data.customerId,
        application_fee:    parseInt (data.amount * data.feePercent),
        metadata:           data.metadata
    })
}

function createExternal (data, callback) {

    return stripe.accounts.createExternalAccount (
        data.managedStripeAccountId,
        { external_account: data.token  }
    )
    .then ( returnSuccess (callback) )
    .catch ( returnError (callback) );
}

function createManaged (data, callback) {

    let createArgs = {
        managed: true,
        country: data.countryShort,
        email: data.email,
        legal_entity: {
            address: {
                city: data.city,
                country: data.countryShort,
                line1: data.address1,
                line2: data.address2,
                postal_code: data.postal,
                state: data.state
            },
            first_name: data.firstName,
            last_name: data.lastName,
            dob: data.dob,
            type: data.entityType,
            personal_id_number: data.piiToken
        },
        external_account: data.bankToken,
        tos_acceptance: {
            date: data.tosAcceptDate,
            ip: data.tosAcceptIP,
            user_agent: data.tosUserAgent
        }
    };

    return stripe.accounts.create(createArgs)
        .then ( returnSuccess (callback) )
        .catch ( returnError (callback) );
}

function getAccountDetails (data, callback) {

    stripe.accounts.retrieve (data.id)
        .then ( returnSuccess (callback) )
        .catch ( returnError (callback) );

}

function refund (data) {
    return stripe.refunds.create({
        charge: data.chargeId,
        refund_application_fee: data.refundFee,
        reverse_transfer: data.reverseTransfer,
        reason: data.reason,
        metadata: data.metadata
    })
}


//// Public --------------------------------------------------------------------------------------



exports.init = function (options)  {

    if (options && _.isObject(options)) _.extend (config, options);

    let api_key = config.api_key;

    if (api_key && _.isString(api_key) && api_key.length) {
        stripe = require('stripe')(api_key);
        stripe.setApiVersion('2016-07-06');
        utilities.logger.info("Payments initialized");
        exports.createCharge = createCharge;
        // exports.createCustomer = createCustomer;
        exports.createExternal = createExternal;
        exports.createManaged = createManaged;
        exports.getAccountDetails = getAccountDetails;
        exports.refund = refund;
    } else {
        utilities.logger.error("Stripe API Key not present.");
    }

};



exports.createCharge = utilities.uninitialized;
// exports.createCustomer = utilities.uninitialized;
exports.createExternal = utilities.uninitialized;
exports.createManaged = utilities.uninitialized;
exports.getAccountDetails = utilities.uninitialized;
exports.refund = utilities.uninitialized;

==> cetus-8.0.30.tgz: package/payments/index.js <==
"use strict";

let _ =   					require('underscore'),
	stripe =				null,
	utilities =   			require('../utilities/index'),
	config =   				require('./config'),
	logErrorAndReturn =     function (e, result, callback) {
                                let err = null;
                                if (e) {
                                    err = new utilities.error.aws (e.code);
                                    utilities.logger.error(e.stack);
                                }
                                if (callback) return callback (err, result);
                            },
    initilized =            false,
    returnSuccess =         function (parent) { return (data) => parent (null, data) },
    returnError =           function (parent) { return function (err) {
                                utilities.logger.error(err);
                                return parent (new utilities.error.stp (err.type));
                            };};




function createCharge (data) {
    return stripe.charges.create ({
        amount:             data.amount,
        currency:           data.currency,
        destination:        data.destination,
        source:             data.ccToken,
        // customer:           data.customerId,
        application_fee:    parseInt (data.amount * data.feePercent),
        metadata:           data.metadata
    })
}

function createExternal (data, callback) {
    return stripe.accounts.createExternalAccount(data.managedStripeAccountId, {external_account: data.token});
}

function createManaged (data, callback) {

    let createArgs = {
        managed: true,
        country: data.countryShort,
        email: data.email,
        legal_entity: {
            address: {
                city: data.city,
                country: data.countryShort,
                line1: data.address1,
                line2: data.address2,
                postal_code: data.postal,
                state: data.state
            },
            first_name: data.firstName,
            last_name: data.lastName,
            dob: data.dob,
            type: data.entityType,
            personal_id_number: data.piiToken
        },
        external_account: data.bankToken,
        tos_acceptance: {
            date: data.tosAcceptDate,
            ip: data.tosAcceptIP,
            user_agent: data.tosUserAgent
        }
    };

    return stripe.accounts.create(createArgs);
}


/*function createManaged (data, callback) {

    let createArgs = {
        managed: true,
        country: data.countryShort,
        email: data.email,
        legal_entity: {
            address: {
                city: data.city,
                country: data.countryShort,
                line1: data.address1,
                line2: data.address2,
                postal_code: data.postal,
                state: data.state
            },
            first_name: data.firstName,
            last_name: data.lastName,
            dob: data.dob,
            type: data.entityType,
            personal_id_number: data.piiToken
        },
        external_account: data.bankToken,
        tos_acceptance: {
            date: data.tosAcceptDate,
            ip: data.tosAcceptIP,
            user_agent: data.tosUserAgent
        }
    };

    return stripe.accounts.create(createArgs)
        .then ( returnSuccess (callback) )
        .catch ( returnError (callback) );
}*/

function getAccountDetails (data, callback) {

    stripe.accounts.retrieve (data.id)
        .then ( returnSuccess (callback) )
        .catch ( returnError (callback) );

}

function refund (data) {
    return stripe.refunds.create({
        charge: data.chargeId,
        refund_application_fee: data.refundFee,
        reverse_transfer: data.reverseTransfer,
        reason: data.reason,
        metadata: data.metadata
    });
}


//// Public --------------------------------------------------------------------------------------



exports.init = function (options)  {

    if (options && _.isObject(options)) _.extend (config, options);

    let api_key = config.api_key;

    if (api_key && _.isString(api_key) && api_key.length) {
        stripe = require('stripe')(api_key);
        stripe.setApiVersion('2016-07-06');
        utilities.logger.info("Payments initialized");
        exports.createCharge = createCharge;
        // exports.createCustomer = createCustomer;
        exports.createExternal = createExternal;
        exports.createManaged = createManaged;
        exports.getAccountDetails = getAccountDetails;
        exports.refund = refund;
    } else {
        utilities.logger.error("Stripe API Key not present.");
    }

};



exports.createCharge = utilities.uninitialized;
// exports.createCustomer = utilities.uninitialized;
exports.createExternal = utilities.uninitialized;
exports.createManaged = utilities.uninitialized;
exports.getAccountDetails = utilities.uninitialized;
exports.refund = utilities.uninitialized;
